==> haskell-contravariant-1.5.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.5.1
id: contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
key: contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
license: BSD-3-Clause
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors.
category: Control, Data
abi: 83bb1f7d9458cdd772cc62b51f405eb5
exposed: True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-1.5.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-1.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/contravariant-1.5.1
hs-libraries: HScontravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
depends:
    StateVar-1.1.1.1-2ewTKofpCGhC2np5dyFIaR base-4.12.0.0
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.5.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.5.2
id: contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
key: contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
license: BSD-3-Clause
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors.
category: Control, Data
abi: eb8ca399d95a6ce048bc34982374969a
exposed: True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-1.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-1.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/contravariant-1.5.2
hs-libraries: HScontravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
depends:
    StateVar-1.1.1.1-2ewTKofpCGhC2np5dyFIaR base-4.12.0.0
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
